@@ -1,11 +1,10 @@
-from datetime import datetime
-
 from django.utils.translation import ugettext as _
+from django.utils import timezone
 
 
 def make_approved(modeladmin, request, queryset):
     for item in queryset:
-        item.approved = datetime.now()
+        item.approved = timezone.now()
         item.save()
 make_approved.allow_tags = True
 make_approved.short_description = _("Make approved")
